==> pmml-model-gwt-1.1.11.jar: org/dmg/pmml/TimeAnchor.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.adapters.IntegerAdapter;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}TimeCycle" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}TimeException" maxOccurs="2" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type" type="{http://www.dmg.org/PMML-4_2}TIME-ANCHOR" />
 *       &lt;attribute name="offset" type="{http://www.dmg.org/PMML-4_2}INT-NUMBER" />
 *       &lt;attribute name="stepsize" type="{http://www.dmg.org/PMML-4_2}INT-NUMBER" />
 *       &lt;attribute name="displayName" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "timeCycles",
    "timeExceptions"
})
@XmlRootElement(name = "TimeAnchor", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_0)
public class TimeAnchor
    extends PMMLObject
{

    @XmlElement(name = "TimeCycle", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<TimeCycle> timeCycles;
    @XmlElement(name = "TimeException", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<TimeException> timeExceptions;
    @XmlAttribute(name = "type")
    protected TimeAnchorType type;
    @XmlAttribute(name = "offset")
    @XmlJavaTypeAdapter(IntegerAdapter.class)
    protected Integer offset;
    @XmlAttribute(name = "stepsize")
    @XmlJavaTypeAdapter(IntegerAdapter.class)
    protected Integer stepsize;
    @XmlAttribute(name = "displayName")
    @XmlSchemaType(name = "anySimpleType")
    protected String displayName;

    /**
     * Gets the value of the timeCycles property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeCycles property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeCycles().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeCycle }
     * 
     * 
     */
    public List<TimeCycle> getTimeCycles() {
        if (timeCycles == null) {
            timeCycles = new ArrayList<TimeCycle>();
        }
        return this.timeCycles;
    }

    /**
     * Gets the value of the timeExceptions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeExceptions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeExceptions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeException }
     * 
     * 
     */
    public List<TimeException> getTimeExceptions() {
        if (timeExceptions == null) {
            timeExceptions = new ArrayList<TimeException>();
        }
        return this.timeExceptions;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TimeAnchorType }
     *     
     */
    public TimeAnchorType getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeAnchorType }
     *     
     */
    public void setType(TimeAnchorType value) {
        this.type = value;
    }

    /**
     * Gets the value of the offset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getOffset() {
        return offset;
    }

    /**
     * Sets the value of the offset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOffset(Integer value) {
        this.offset = value;
    }

    /**
     * Gets the value of the stepsize property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getStepsize() {
        return stepsize;
    }

    /**
     * Sets the value of the stepsize property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStepsize(Integer value) {
        this.stepsize = value;
    }

    /**
     * Gets the value of the displayName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDisplayName() {
        return displayName;
    }

    /**
     * Sets the value of the displayName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDisplayName(String value) {
        this.displayName = value;
    }

    public TimeAnchor withTimeCycles(TimeCycle... values) {
        if (values!= null) {
            for (TimeCycle value: values) {
                getTimeCycles().add(value);
            }
        }
        return this;
    }

    public TimeAnchor withTimeCycles(Collection<TimeCycle> values) {
        if (values!= null) {
            getTimeCycles().addAll(values);
        }
        return this;
    }

    public TimeAnchor withTimeExceptions(TimeException... values) {
        if (values!= null) {
            for (TimeException value: values) {
                getTimeExceptions().add(value);
            }
        }
        return this;
    }

    public TimeAnchor withTimeExceptions(Collection<TimeException> values) {
        if (values!= null) {
            getTimeExceptions().addAll(values);
        }
        return this;
    }

    public TimeAnchor withType(TimeAnchorType value) {
        setType(value);
        return this;
    }

    public TimeAnchor withOffset(Integer value) {
        setOffset(value);
        return this;
    }

    public TimeAnchor withStepsize(Integer value) {
        setStepsize(value);
        return this;
    }

    public TimeAnchor withDisplayName(String value) {
        setDisplayName(value);
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.timeCycles!= null))&&(i<this.timeCycles.size())); i ++) {
            status = this.timeCycles.get(i).accept(visitor);
        }
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.timeExceptions!= null))&&(i<this.timeExceptions.size())); i ++) {
            status = this.timeExceptions.get(i).accept(visitor);
        }
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.1.14.jar: org/dmg/pmml/TimeAnchor.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.adapters.IntegerAdapter;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}TimeCycle" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}TimeException" maxOccurs="2" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type" type="{http://www.dmg.org/PMML-4_2}TIME-ANCHOR" />
 *       &lt;attribute name="offset" type="{http://www.dmg.org/PMML-4_2}INT-NUMBER" />
 *       &lt;attribute name="stepsize" type="{http://www.dmg.org/PMML-4_2}INT-NUMBER" />
 *       &lt;attribute name="displayName" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "timeCycles",
    "timeExceptions"
})
@XmlRootElement(name = "TimeAnchor", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_0)
public class TimeAnchor
    extends PMMLObject
{

    @XmlAttribute(name = "type")
    protected TimeAnchorType type;
    @XmlAttribute(name = "offset")
    @XmlJavaTypeAdapter(IntegerAdapter.class)
    protected Integer offset;
    @XmlAttribute(name = "stepsize")
    @XmlJavaTypeAdapter(IntegerAdapter.class)
    protected Integer stepsize;
    @XmlAttribute(name = "displayName")
    @XmlSchemaType(name = "anySimpleType")
    protected String displayName;
    @XmlElement(name = "TimeCycle", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<TimeCycle> timeCycles;
    @XmlElement(name = "TimeException", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<TimeException> timeExceptions;

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TimeAnchorType }
     *     
     */
    public TimeAnchorType getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeAnchorType }
     *     
     */
    public void setType(TimeAnchorType value) {
        this.type = value;
    }

    /**
     * Gets the value of the offset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getOffset() {
        return offset;
    }

    /**
     * Sets the value of the offset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOffset(Integer value) {
        this.offset = value;
    }

    /**
     * Gets the value of the stepsize property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getStepsize() {
        return stepsize;
    }

    /**
     * Sets the value of the stepsize property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStepsize(Integer value) {
        this.stepsize = value;
    }

    /**
     * Gets the value of the displayName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDisplayName() {
        return displayName;
    }

    /**
     * Sets the value of the displayName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDisplayName(String value) {
        this.displayName = value;
    }

    /**
     * Gets the value of the timeCycles property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeCycles property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeCycles().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeCycle }
     * 
     * 
     */
    public List<TimeCycle> getTimeCycles() {
        if (timeCycles == null) {
            timeCycles = new ArrayList<TimeCycle>();
        }
        return this.timeCycles;
    }

    /**
     * Gets the value of the timeExceptions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeExceptions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeExceptions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeException }
     * 
     * 
     */
    public List<TimeException> getTimeExceptions() {
        if (timeExceptions == null) {
            timeExceptions = new ArrayList<TimeException>();
        }
        return this.timeExceptions;
    }

    public TimeAnchor withType(TimeAnchorType value) {
        setType(value);
        return this;
    }

    public TimeAnchor withOffset(Integer value) {
        setOffset(value);
        return this;
    }

    public TimeAnchor withStepsize(Integer value) {
        setStepsize(value);
        return this;
    }

    public TimeAnchor withDisplayName(String value) {
        setDisplayName(value);
        return this;
    }

    public TimeAnchor withTimeCycles(TimeCycle... values) {
        if (values!= null) {
            for (TimeCycle value: values) {
                getTimeCycles().add(value);
            }
        }
        return this;
    }

    public TimeAnchor withTimeCycles(Collection<TimeCycle> values) {
        if (values!= null) {
            getTimeCycles().addAll(values);
        }
        return this;
    }

    public TimeAnchor withTimeExceptions(TimeException... values) {
        if (values!= null) {
            for (TimeException value: values) {
                getTimeExceptions().add(value);
            }
        }
        return this;
    }

    public TimeAnchor withTimeExceptions(Collection<TimeException> values) {
        if (values!= null) {
            getTimeExceptions().addAll(values);
        }
        return this;
    }

    public boolean hasTimeCycles() {
        return ((this.timeCycles!= null)&&(this.timeCycles.size()> 0));
    }

    public boolean hasTimeExceptions() {
        return ((this.timeExceptions!= null)&&(this.timeExceptions.size()> 0));
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.timeCycles!= null))&&(i<this.timeCycles.size())); i ++) {
            status = this.timeCycles.get(i).accept(visitor);
        }
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.timeExceptions!= null))&&(i<this.timeExceptions.size())); i ++) {
            status = this.timeExceptions.get(i).accept(visitor);
        }
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
